==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/OSDiskImageSecurityProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.OSDiskImageSecurityProfileArgs.builder
import com.pulumi.azurenative.compute.kotlin.enums.ConfidentialVMEncryptionType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Contains security profile for an OS disk image.
 * @property confidentialVMEncryptionType confidential VM encryption types
 * @property secureVMDiskEncryptionSetId secure VM disk encryption set id
 */
public data class OSDiskImageSecurityProfileArgs(
    public val confidentialVMEncryptionType: Output<Either<String, ConfidentialVMEncryptionType>>? =
        null,
    public val secureVMDiskEncryptionSetId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.OSDiskImageSecurityProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.OSDiskImageSecurityProfileArgs =
        com.pulumi.azurenative.compute.inputs.OSDiskImageSecurityProfileArgs.builder()
            .confidentialVMEncryptionType(
                confidentialVMEncryptionType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .secureVMDiskEncryptionSetId(secureVMDiskEncryptionSetId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [OSDiskImageSecurityProfileArgs].
 */
@PulumiTagMarker
public class OSDiskImageSecurityProfileArgsBuilder internal constructor() {
    private var confidentialVMEncryptionType: Output<Either<String, ConfidentialVMEncryptionType>>? =
        null

    private var secureVMDiskEncryptionSetId: Output<String>? = null

    /**
     * @param value confidential VM encryption types
     */
    @JvmName("iutlnsnajovbhxdp")
    public suspend
    fun confidentialVMEncryptionType(`value`: Output<Either<String, ConfidentialVMEncryptionType>>) {
        this.confidentialVMEncryptionType = value
    }

    /**
     * @param value secure VM disk encryption set id
     */
    @JvmName("xvljewmarrempjvu")
    public suspend fun secureVMDiskEncryptionSetId(`value`: Output<String>) {
        this.secureVMDiskEncryptionSetId = value
    }

    /**
     * @param value confidential VM encryption types
     */
    @JvmName("jgafkqybslfljgvd")
    public suspend
    fun confidentialVMEncryptionType(`value`: Either<String, ConfidentialVMEncryptionType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.confidentialVMEncryptionType = mapped
    }

    /**
     * @param value confidential VM encryption types
     */
    @JvmName("cnrfatlfofqyelni")
    public fun confidentialVMEncryptionType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ConfidentialVMEncryptionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.confidentialVMEncryptionType = mapped
    }

    /**
     * @param value confidential VM encryption types
     */
    @JvmName("xbmqcxvgfwhtjtlx")
    public fun confidentialVMEncryptionType(`value`: ConfidentialVMEncryptionType) {
        val toBeMapped = Either.ofRight<String, ConfidentialVMEncryptionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.confidentialVMEncryptionType = mapped
    }

    /**
     * @param value secure VM disk encryption set id
     */
    @JvmName("iwcuguqyljeyckbm")
    public suspend fun secureVMDiskEncryptionSetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secureVMDiskEncryptionSetId = mapped
    }

    internal fun build(): OSDiskImageSecurityProfileArgs = OSDiskImageSecurityProfileArgs(
        confidentialVMEncryptionType = confidentialVMEncryptionType,
        secureVMDiskEncryptionSetId = secureVMDiskEncryptionSetId,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/OSDiskImageSecurityProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.OSDiskImageSecurityProfileArgs.builder
import com.pulumi.azurenative.compute.kotlin.enums.ConfidentialVMEncryptionType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Contains security profile for an OS disk image.
 * @property confidentialVMEncryptionType confidential VM encryption types
 * @property secureVMDiskEncryptionSetId secure VM disk encryption set id
 */
public data class OSDiskImageSecurityProfileArgs(
    public val confidentialVMEncryptionType: Output<Either<String, ConfidentialVMEncryptionType>>? =
        null,
    public val secureVMDiskEncryptionSetId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.OSDiskImageSecurityProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.OSDiskImageSecurityProfileArgs =
        com.pulumi.azurenative.compute.inputs.OSDiskImageSecurityProfileArgs.builder()
            .confidentialVMEncryptionType(
                confidentialVMEncryptionType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .secureVMDiskEncryptionSetId(secureVMDiskEncryptionSetId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [OSDiskImageSecurityProfileArgs].
 */
@PulumiTagMarker
public class OSDiskImageSecurityProfileArgsBuilder internal constructor() {
    private var confidentialVMEncryptionType: Output<Either<String, ConfidentialVMEncryptionType>>? =
        null

    private var secureVMDiskEncryptionSetId: Output<String>? = null

    /**
     * @param value confidential VM encryption types
     */
    @JvmName("tunxidksqlikyhbn")
    public suspend
    fun confidentialVMEncryptionType(`value`: Output<Either<String, ConfidentialVMEncryptionType>>) {
        this.confidentialVMEncryptionType = value
    }

    /**
     * @param value secure VM disk encryption set id
     */
    @JvmName("teevpsbscshrknid")
    public suspend fun secureVMDiskEncryptionSetId(`value`: Output<String>) {
        this.secureVMDiskEncryptionSetId = value
    }

    /**
     * @param value confidential VM encryption types
     */
    @JvmName("ykgvdwotpolsmbfj")
    public suspend
    fun confidentialVMEncryptionType(`value`: Either<String, ConfidentialVMEncryptionType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.confidentialVMEncryptionType = mapped
    }

    /**
     * @param value confidential VM encryption types
     */
    @JvmName("jagtmcamtnaadvjg")
    public fun confidentialVMEncryptionType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ConfidentialVMEncryptionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.confidentialVMEncryptionType = mapped
    }

    /**
     * @param value confidential VM encryption types
     */
    @JvmName("gopxmvfdkyppdrhu")
    public fun confidentialVMEncryptionType(`value`: ConfidentialVMEncryptionType) {
        val toBeMapped = Either.ofRight<String, ConfidentialVMEncryptionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.confidentialVMEncryptionType = mapped
    }

    /**
     * @param value secure VM disk encryption set id
     */
    @JvmName("qlcumxnqyciepste")
    public suspend fun secureVMDiskEncryptionSetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secureVMDiskEncryptionSetId = mapped
    }

    internal fun build(): OSDiskImageSecurityProfileArgs = OSDiskImageSecurityProfileArgs(
        confidentialVMEncryptionType = confidentialVMEncryptionType,
        secureVMDiskEncryptionSetId = secureVMDiskEncryptionSetId,
    )
}
